@@ -21,7 +21,7 @@ impl Batch {
 		}
 	}
 	pub fn typ<'a>(&self, objs: &'a [Primitive]) -> &'a ObjStore {
-		get(objs, self.idxs.get(0).unwrap())
+		get(objs, self.idxs.get(0).valid())
 	}
 	pub fn contains(&self, objs: &[Primitive], (o, z): (&ObjStore, u32)) -> bool {
 		let (t, idxs) = (self.typ(objs), &self.idxs);
@@ -72,7 +72,7 @@ impl Batch {
 				l.intersects(obj.base())
 			})
 	}
-	pub fn redraw(&mut self, objs: &mut [Primitive]) -> (u32, State) {
+	pub fn redraw(&mut self, aspect: Vec2, objs: &mut [Primitive]) -> (u32, State) {
 		let Self { xyzw, rgba, uv, idxs, .. } = self;
 
 		let (len, mut state) = idxs.iter_mut().fold((0, State::empty()), |(start, flush), Obj { idx, size }| {
@@ -83,9 +83,9 @@ impl Batch {
 
 				if state.contains(State::TYPE) {
 					let to = usize(start + new_size);
-					xyzw.resize_def(to * 4);
-					rgba.resize_def(to * 4);
-					uv.resize_def(to * 2);
+					xyzw.resize(to * 4, f16(0));
+					rgba.resize(to * 4, 0);
+					uv.resize(to * 2, f16(0));
 				} else {
 					if new_size > *size {
 						const O: f16 = f16::ZERO;
@@ -108,7 +108,8 @@ impl Batch {
 				*size = new_size;
 
 				let (z, s) = <(f32, usize)>::to((*idx, start));
-				o.obj().write_mesh((f16(1. - z / 1000.), *state, &mut xyzw[s * 4..], &mut rgba[s * 4..], &mut uv[s * 2..]));
+				o.obj()
+					.write_mesh(aspect, (f16(1. - z / 1000.), *state, &mut xyzw[s * 4..], &mut rgba[s * 4..], &mut uv[s * 2..]));
 			}
 			(start + *size, flush | *state)
 		});
