@@ -9,7 +9,7 @@ mod util;
 
 use super::{parts::*, render::*, sugar::Theme};
 use crate::events::{Event::*, EventReply::*, *};
-use crate::uses::{math::*, GL::font::Font, GL::window::*, *};
+use crate::uses::{math::*, GL::font::Font, *};
 use util::Caret;
 
 pub use {button::Button, label::Label, layout::Layout, line::LineEdit, selector::Selector, slider::Slider, text::TextEdit};
