@@ -13,7 +13,7 @@ impl Objects {
 	}
 	pub fn shrink(&mut self, to: u32) {
 		let Self { batches, objs, .. } = self;
-		batches.retain_mut(|b| !b.shrink_and_empty(objs, to));
+		batches.keep_mut(|b| !b.shrink_and_empty(objs, to));
 		objs.truncate(usize(to));
 	}
 	pub fn batch(&mut self) {
@@ -36,7 +36,7 @@ impl Objects {
 			})
 			.map(|(n, _)| n)
 		{
-			batches.retain_mut(|b| !b.shrink_and_empty(objs, u32(first_invalid)));
+			batches.keep_mut(|b| !b.shrink_and_empty(objs, u32(first_invalid)));
 
 			objs.iter().enumerate().skip(first_invalid).for_each(|(z, o)| {
 				let (z, o) = (u32(z), &o.o);
@@ -60,13 +60,15 @@ impl Objects {
 			*first_transparent = batches.iter().position(|b| b.typ(objs).obj().ordered()).unwrap_or(batches.len());
 		}
 	}
-	pub fn flush(&mut self, idxs: &mut Vec<u16>, xyzw: &mut Vec<f16>, rgba: &mut Vec<u8>, uv: &mut Vec<f16>) -> (Option<usize>, Option<usize>, Option<usize>, Option<usize>) {
+	pub fn flush(
+		&mut self, aspect: Vec2, idxs: &mut Vec<u16>, xyzw: &mut Vec<f16>, rgba: &mut Vec<u8>, uv: &mut Vec<f16>,
+	) -> (Option<usize>, Option<usize>, Option<usize>, Option<usize>) {
 		let Self { batches, objs, .. } = self;
 
 		batches
 			.iter_mut()
 			.fold(((None, None, None, None), State::empty(), 0, 0), |(mut flush, mut state, idx_start, batch_start), b| {
-				let (batch_size, s) = b.redraw(objs);
+				let (batch_size, s) = b.redraw(aspect, objs);
 				state |= s;
 
 				if state.contains(State::RESIZED) {
