@@ -1,7 +1,7 @@
 use super::obj::*;
 use super::sprite::{gui__pos_col_tex_vs, sampler};
 use crate::uses::{math::*, *};
-use GL::{font::*, shader::*, window::*, VaoBinding};
+use GL::{font::*, shader::*, VaoBinding};
 
 pub struct Text<'r, 'a> {
 	pub pos: Vec2,
@@ -21,7 +21,7 @@ impl<'a> Text<'_, 'a> {
 				*x += font.kern(*last_c, c);
 				*last_c = c;
 				let ch = font.char(c);
-				Some((*x, ch)).filter(|(x, ch)| (*x + ch.coord.z()) * scale <= max_width).map(|r| {
+				Some((*x, ch)).filter(|(x, ch)| (x + ch.coord.z()) * scale <= max_width).map(|r| {
 					*x += ch.adv;
 					(r, i)
 				})
@@ -114,7 +114,7 @@ impl Object for TextImpl {
 	fn base(&self) -> &Base {
 		&self.base
 	}
-	fn write_mesh(&self, (z, state, mut xyzw, mut rgba, mut uv): BatchRange) {
+	fn write_mesh(&self, aspect: Vec2, (z, state, mut xyzw, mut rgba, mut uv): BatchRange) {
 		if self.text.is_empty() {
 			return;
 		}
@@ -125,7 +125,7 @@ impl Object for TextImpl {
 		} = base;
 
 		if state.contains(State::XYZW) {
-			let (aspect, s) = (Window::_aspect(), *scale);
+			let (aspect, s) = (aspect, *scale);
 
 			let (mut x, mut last_c) = (-font.char(text.chars().next().unwrap_or(' ')).coord.x(), 0 as char);
 			for c in text.chars() {
@@ -166,7 +166,7 @@ impl Object for TextImpl {
 		}
 	}
 	fn batch_draw(&self, b: &VaoBinding<u16>, (offset, num): (u16, u16)) {
-		let s = UnsafeOnce!(Shader, { EXPECT!(Shader::new((gui__pos_col_tex_vs, gui_sdftext_ps))) });
+		let s = UnsafeOnce!(Shader, { Shader::pure((gui__pos_col_tex_vs, gui_sdftext_ps)) });
 
 		let t = self.font.tex().Bind(sampler());
 		let _ = Uniforms!(s, ("tex", &t));
@@ -209,19 +209,15 @@ SHADER!(
 
 		vec4 correction = vec4(vec3(pix_l, pix_r, pix_n), pix);
 
-		/*// Antialias
+		/* // Antialias
 		float center = texture(tex, glTexCoord.xy).r;
 		float dscale = .354; // half of 1/sqrt2
 		float friends = .5; // scale value to apply to neighbours
-
 		vec2 duv = dscale * (dFdx(v_uv) + dFdy(v_uv));
 		vec4 box = vec4(v_uv-duv, v_uv+duv);
-
 		vec4 c = samp( box.xy ) + samp( box.zw ) + samp( box.xw ) + samp( box.zy );
 		float sum = 4; // 4 neighbouring samples
-
-		rgbaOut = fontColor * (center + friends * c) / (1. + sum*friends);
-		*/
+		rgbaOut = fontColor * (center + friends * c) / (1. + sum*friends); */
 
 		glFragColor = glColor * correction;
 	}"
