@@ -3,7 +3,7 @@ use crate::events::*;
 use crate::uses::{math::*, *};
 use GL::{spec, Frame, Vao, RGB, RGBA};
 
-macro_rules! Draw {
+macro_rules! DRAW {
 	($t: ty, $draw_spec: tt) => {
 		impl<'l> DrawablePrimitive<'l> for $t {
 			fn draw(self, obj_n: u32, clip: &Crop, r: &mut Renderer) {
@@ -36,13 +36,13 @@ macro_rules! Draw {
 pub trait DrawablePrimitive<'l> {
 	fn draw(self, _: u32, _: &Crop, _: &mut Renderer);
 }
-Draw!(Rect, Rect);
-Draw!(Sprite<'l, RGB>, ImgRGB);
-Draw!(Sprite<'l, RGBA>, ImgRGBA);
-Draw!(Sprite9<'l, RGB>, Img9RGB);
-Draw!(Sprite9<'l, RGBA>, Img9RGBA);
-Draw!(Frame9<'l>, Frame9);
-Draw!(Text<'l, '_>, Text);
+DRAW!(Rect, Rect);
+DRAW!(Sprite<'l, RGB>, ImgRGB);
+DRAW!(Sprite<'l, RGBA>, ImgRGBA);
+DRAW!(Sprite9<'l, RGB>, Img9RGB);
+DRAW!(Sprite9<'l, RGBA>, Img9RGBA);
+DRAW!(Frame9<'l>, Frame9);
+DRAW!(Text<'l, '_>, Text);
 
 #[derive(Default)]
 pub struct RenderLock<'l> {
@@ -66,7 +66,7 @@ impl<'l> RenderLock<'l> {
 	}
 	pub fn draw(&mut self, prim: impl DrawablePrimitive<'l>) {
 		let Self { r, n, clip, .. } = self;
-		prim.draw(*n, EXPECT!(clip.iter().last()), r);
+		prim.draw(*n, clip.last().valid(), r);
 		*n += 1;
 	}
 	pub fn logic(&mut self, b_box: Crop, func: impl 'l + FnMut(&Event, bool, Vec2) -> EventReply, id: LogicId) {
@@ -75,7 +75,7 @@ impl<'l> RenderLock<'l> {
 	}
 	pub fn draw_with_logic(&mut self, prim: impl DrawablePrimitive<'l>, func: impl 'l + FnMut(&Event, bool, Vec2) -> EventReply, id: LogicId) {
 		let Self { r, n, clip, logics, .. } = self;
-		prim.draw(*n, EXPECT!(clip.iter().last()), r);
+		prim.draw(*n, clip.last().valid(), r);
 		let (id, bound, func) = (id, LogicBound::Obj(*n), Box::new(func));
 		logics.push(LogicStorage { id, bound, func });
 		*n += 1;
@@ -97,6 +97,9 @@ impl<'l> RenderLock<'l> {
 	pub fn mouse_pos(&self) -> Vec2 {
 		self.r.mouse_pos
 	}
+	pub fn aspect(&self) -> Vec2 {
+		self.r.aspect
+	}
 	pub fn unlock(self, w: &mut impl Frame, events: &mut Vec<Event>) -> Renderer {
 		debug_assert!({
 			super::sugar::borrow_map().clear();
@@ -132,7 +135,9 @@ impl Renderer {
 		RenderLock {
 			r: self,
 			clip: vec![((-L, -L), (L, L))],
-			..Def()
+			n: 0,
+			logics: vec![],
+			l: Dummy,
 		}
 	}
 	fn consume_events(&mut self, logics: Vec<LogicStorage>, events: &mut Vec<Event>) {
@@ -229,9 +234,10 @@ impl Renderer {
 			aspect,
 			..
 		} = self;
+
 		if !flush.is_empty() {
 			objs.batch();
-			let flush = objs.flush(&mut idxs.buff, &mut xyzw.buff, &mut rgba.buff, &mut uv.buff);
+			let flush = objs.flush(frame.aspect(), &mut idxs.buff, &mut xyzw.buff, &mut rgba.buff, &mut uv.buff);
 
 			idxs.flush(flush.0, |o| vao.BindIdxs(o));
 			xyzw.flush(flush.1, |o| vao.AttribFmt(o, (0, 4)));
@@ -287,7 +293,7 @@ impl<T: spec::Buffer, D: Copy> Storage<T, D> {
 			}
 
 			*size = new_size;
-			*obj = spec::ArrObject::new((&buff[..], gl::DYNAMIC_STORAGE_BIT | gl::MAP_WRITE_BIT));
+			*obj = spec::ArrObject::new((buff, gl::DYNAMIC_STORAGE_BIT | gl::MAP_WRITE_BIT));
 			rebind(obj);
 		}
 	}
@@ -298,8 +304,7 @@ type ArrStorage<T> = Storage<spec::Attribute, T>;
 struct LogicStorage<'l> {
 	id: LogicId,
 	bound: LogicBound,
-	// TODO trait alias all
-	func: Box<dyn 'l + FnMut(&Event, bool, Vec2) -> EventReply>,
+	func: Box<dyn 'l + FnMut(&Event, bool, Vec2) -> EventReply>, // TODO trait alias all
 }
 enum LogicBound {
 	Crop(Crop),
