@@ -7,19 +7,19 @@ pub struct Animation<'a, S: TexSize> {
 	a: Dummy<&'a u32>,
 }
 impl<'a, S: TexSize> Animation<'a, S> {
-	pub fn from_file(name: &str, atlas: &'a TexAtlas<S>) -> Self {
-		let anim_desc = CONCAT!("res/", name, "/desc");
-		let data = EXPECT!(FS::Load::Text(&anim_desc));
+	pub fn from_file(name: &str, atlas: &'a TexAtlas<S>) -> Res<Self> {
+		let anim_desc = format!("res/{name}/desc");
+		let data = FS::Load::Text(&anim_desc)?;
 
 		let mut time = 0.;
 		let (starts, frames): (Vec<_>, Vec<_>) = data
 			.lines()
 			.filter_map(|l| {
 				if "d " == slice((l, 2)) {
-					time += EXPECT!(slice((2, l)).parse::<f32>());
+					time += OR_DEFAULT!(slice((2, l)).parse::<f32>(), "Animation {anim_desc} has invalid format, {}");
 					None
 				} else {
-					let t = atlas.load(&CONCAT!(name, "/", l));
+					let t = atlas.load(&format!("{name}/{l}"));
 					let f = (time, t);
 					time += 1.;
 					Some(f)
@@ -27,25 +27,28 @@ impl<'a, S: TexSize> Animation<'a, S> {
 			})
 			.unzip();
 
-		ASSERT!(!frames.is_empty(), "Empty animation file {}", anim_desc);
-		let frames: Vec<_> = frames
+		let frames = frames
 			.into_iter()
 			.zip(starts.iter().zip(starts.iter().chain(&[time]).skip(1)))
 			.map(|(f, (&s, &e))| ((s, e).div(time), f))
-			.collect();
+			.collect_vec();
 
-		Self { frames, c: 0, a: Dummy }
+		if frames.is_empty() {
+			Err(format!("Empty animation file {anim_desc}"))
+		} else {
+			Ok(Self { frames, c: 0, a: Dummy })
+		}
 	}
 	pub fn frame(&mut self, t: f32) -> &VTex2d<S, u8> {
 		let Self { frames, c, .. } = self;
-		ASSERT!(t <= 1., "Animation assumes time in (0..1), given {}", t);
+		ASSERT!(t <= 1., "Animation assumes time in (0..1), given {t}");
 
-		for (n, ((b, e), guess)) in frames.iter().enumerate().skip(*c).chain(frames.iter().enumerate().take(*c)) {
+		for (n, ((b, e), guess)) in frames.iter().skip(*c).chain(frames.iter().take(*c)).enumerate() {
 			if t >= *b && t <= *e {
 				*c = n;
 				return guess.get();
 			}
 		}
-		EXPECT!(frames.last()).1.get()
+		frames.last().valid().1.get()
 	}
 }
