@@ -5,13 +5,6 @@ macro_rules! LOGGER {
 	};
 }
 
-#[macro_export]
-macro_rules! CONCAT {
-	($($t: expr),+) => {
-		[$($t),+].concat()
-	};
-}
-
 #[macro_export]
 macro_rules! EXPECT {
 	($e: expr) => {{
@@ -25,23 +18,9 @@ macro_rules! EXPECT {
 }
 
 #[macro_export]
-macro_rules! PASS {
-	($e: expr) => {
-		Res($e)?
-	};
-	($e: expr, $w: expr) => {
-		Res($e).map_err($w)?
-	};
-}
-
-#[macro_export]
-macro_rules! OR_DEF {
-	($e: expr) => {{
-		EXPECT_OR_DEF_IMPL!($e, "{}")
-	}};
-	($e: expr, $($t: tt)+) => {{
-		EXPECT_OR_DEF_IMPL!($e, $($t)+)
-	}}
+macro_rules! OR_DEFAULT {
+	($e: expr) => { EXPECT_OR_DEF_IMPL!($e, "{}") };
+	($e: expr, $($t: tt)+) => { EXPECT_OR_DEF_IMPL!($e, $($t)+) };
 }
 #[macro_export]
 macro_rules! EXPECT_OR_DEF_IMPL {
@@ -50,143 +29,133 @@ macro_rules! EXPECT_OR_DEF_IMPL {
 		use logging::UniformUnwrapOrDefault;
 		if e.uni_is_err() {
 			let (v, e) = e.uni_err();
-			FAILED!($($t)+, e);
+			FAIL!($($t)+, e);
 			v
 		} else {
-			e.unwrap()
+			unsafe{ e.unwrap_unchecked() }
 		}
 	}};
 }
 
-#[cfg(not(debug_assertions))]
-#[macro_export]
-macro_rules! FAILED {
-	($($t: tt)+) => {{
-		WARN!($($t)+);
-	}}
-}
-
-#[cfg(debug_assertions)]
-#[macro_export]
-macro_rules! FAILED {
-	($($t: tt)+) => {{
-		ASSERT!(0 == 1, $($t)+);
-	}}
-}
-
 #[cfg(not(debug_assertions))]
 #[macro_export]
 macro_rules! ASSERT {
 	(false, $($t: tt)+) => {{
-		unreachable!()
+		unreachable!();
 	}};
 	($e: expr, $($t: tt)+) => {{}};
 }
-
 #[cfg(debug_assertions)]
 #[macro_export]
 macro_rules! ASSERT {
-	(false, $w: expr) => {{
-		ASSERT_IMPL!("{:?}", $w);
-	}};
-	(false, $($t: tt)+) => {{
-		ASSERT_IMPL!($($t)+);
-	}};
-	($e: expr, $w: expr) => {{
-		if $e {} else {
-			ASSERT_IMPL!("{:?}", $w);
-		}
-	}};
-	($e: expr, $($t: tt)+) => {{
-		if $e {} else {
-			ASSERT_IMPL!($($t)+);
-		}
-	}}
+	(false, $w: literal) => { ASSERT_IMPL!($w) };
+	(false, $w: expr) => { ASSERT_IMPL!("{:?}", $w) };
+	(false, $($t: tt)+) => { ASSERT_IMPL!($($t)+) };
+	($e: expr, $w: literal) => {{ if $e {} else { ASSERT_IMPL!($w) } }};
+	($e: expr, $w: expr) => {{ if $e {} else { ASSERT_IMPL!("{:?}", $w) } }};
+	($e: expr, $($t: tt)+) => {{ if $e {} else { ASSERT_IMPL!($($t)+) } }};
 }
 #[macro_export]
 macro_rules! ASSERT_IMPL {
 	($($t: tt)+) => {{
-		logging::Logger::Log(CONCAT!("A| ", &format!($($t)+), " at ", file!(), ":", &line!().to_string(), "\n"));
-		panic!()
-	}}
-}
-
-#[macro_export]
-macro_rules! ERROR {
-	($e: expr) => {{ ERROR_IMPL!("{:?}", $e); }};
-	($($t: tt)+) => {{ ERROR_IMPL!($($t)+); }}
-}
-#[macro_export]
-macro_rules! ERROR_IMPL {
-	($($t: tt)+) => {{
-		use logging::*;
-		Logger::Log(CONCAT!("E| ", &format!($($t)+), " at ", file!(), ":", &line!().to_string(), "\n"));
-		Logger::Log(format!("{:?}", backtrace::Backtrace::new()));
+		logging::Logger::Log(["A| ", &format!($($t)+), " at ", file!(), ":", &line!().to_string(), "\n"].concat());
 		panic!();
 	}};
 }
 
+#[macro_export]
+macro_rules! ERROR {
+	($e: literal) => { ERROR_IMPL!($e) };
+	($e: expr) => { ERROR_IMPL!("{:?}", $e) };
+	($($t: tt)+) => { ERROR_IMPL!($($t)+) };
+}
+#[macro_export]
+macro_rules! ERROR_IMPL {
+	($($t: tt)+) => {{
+		use logging::*;
+		let bt = backtrace::Backtrace::new();
+		Logger::Log(["E| ", &format!($($t)+), &format!(" at {}:{}\n{bt:?}", file!(), line!())].concat());
+		panic!();
+	}};
+}
+
+#[cfg(not(debug_assertions))]
+#[macro_export]
+macro_rules! FAIL {
+	($($t: tt)+) => { WARN!($($t)+) };
+}
+#[cfg(debug_assertions)]
+#[macro_export]
+macro_rules! FAIL {
+	($($t: tt)+) => { ASSERT!(0 == 1, $($t)+) };
+}
+
 #[macro_export]
 macro_rules! WARN {
-	($e: expr) => {{ WARN_IMPL!("{:?}", $e); }};
-	($($t: tt)+) => {{ WARN_IMPL!($($t)+); }}
+	($e: literal) => { WARN_IMPL!($e) };
+	($e: expr) => { WARN_IMPL!("{:?}", $e) };
+	($($t: tt)+) => { WARN_IMPL!($($t)+) };
 }
 #[macro_export]
 macro_rules! WARN_IMPL {
 	($($t: tt)+) => {{
 		use logging::*;
 		if (Level::WARNING as i32) <= Logger::level() {
-			Logger::Log(CONCAT!("W| ", &format!($($t)+), " at ", file!(), ":", &line!().to_string(), "\n"));
+			Logger::Log(["W| ", &format!($($t)+), " at ", file!(), ":", &line!().to_string(), "\n"].concat());
 		}
 	}};
 }
 
 #[macro_export]
 macro_rules! INFO {
-	($e: expr) => {{ INFO_IMPL!("{:?}", $e); }};
-	($($t: tt)+) => {{ INFO_IMPL!($($t)+); }}
+	($e: literal) => { INFO_IMPL!($e) };
+	($e: expr) => { INFO_IMPL!("{:?}", $e) };
+	($($t: tt)+) => { INFO_IMPL!($($t)+) };
 }
 #[macro_export]
 macro_rules! INFO_IMPL {
 	($($t: tt)+) => {{
 		use logging::*;
 		if (Level::INFO as i32) <= Logger::level() {
-			Logger::Log(CONCAT!("I| ", &format!($($t)+), " at ", file!(), ":", &line!().to_string(), "\n"));
+			Logger::Log(["I| ", &format!($($t)+), " at ", file!(), ":", &line!().to_string(), "\n"].concat());
 		}
-	}}
+	}};
 }
 
 #[cfg(not(debug_assertions))]
 #[macro_export]
 macro_rules! DEBUG {
-	($e: expr) => {{}};
 	($($t: tt)+) => {{}};
 }
-
 #[cfg(debug_assertions)]
 #[macro_export]
 macro_rules! DEBUG {
-	($e: expr) => {{ DEBUG_IMPL!("{:?}", $e); }};
-	($($t: tt)+) => {{ DEBUG_IMPL!($($t)+); }}
+	($e: literal) => { DEBUG_IMPL!($e) };
+	($e: expr) => { DEBUG_IMPL!("{:?}", $e) };
+	($($t: tt)+) => { DEBUG_IMPL!($($t)+) };
 }
 #[macro_export]
 macro_rules! DEBUG_IMPL {
 	($($t: tt)+) => {{
 		use logging::*;
 		if (Level::DEBUG as i32) <= Logger::level() {
-			Logger::Log(CONCAT!("D| ", &format!($($t)+), "\n"));
+			Logger::Log(["D| ", &format!($($t)+), "\n"].concat());
 		}
-	}}
+	}};
 }
 
 #[macro_export]
 macro_rules! PRINT {
-	($e: expr) => {{ _PRINT!("{:?}", $e); }};
-	($($t: tt)+) => {{ _PRINT!($($t)+); }}
+	($e: literal) => { PRINT_IMPL!($e) };
+	($e: expr) => { PRINT_IMPL!("{:?}", $e) };
+	($($t: tt)+) => { PRINT_IMPL!($($t)+) };
 }
 #[macro_export]
-macro_rules! _PRINT {
+macro_rules! PRINT_IMPL {
 	($($t: tt)+) => {{
-		logging::Logger::Log(CONCAT!(&format!($($t)+), "\n"));
-	}}
+		use logging::*;
+		let mut msg = format!($($t)+);
+		msg.push('\n');
+		Logger::Log(msg);
+	}};
 }
