@@ -1,15 +1,5 @@
 use crate::uses::f16;
 
-pub type Mat2 = (Vec2, Vec2);
-pub type Mat3 = (Vec3, Vec3, Vec3);
-pub type Mat4 = (Vec4, Vec4, Vec4, Vec4);
-pub type Mat2x3 = (Vec3, Vec3);
-pub type Mat3x2 = (Vec2, Vec2, Vec2);
-pub type Mat2x4 = (Vec4, Vec4);
-pub type Mat4x2 = (Vec2, Vec2, Vec2, Vec2);
-pub type Mat3x4 = (Vec4, Vec4, Vec4);
-pub type Mat4x3 = (Vec3, Vec3, Vec3, Vec3);
-
 pub type hVec2 = vec2<f16>;
 pub type hVec3 = vec3<f16>;
 pub type hVec4 = vec4<f16>;
@@ -54,6 +44,26 @@ pub type ilVec2 = vec2<isize>;
 pub type ilVec3 = vec3<isize>;
 pub type ilVec4 = vec4<isize>;
 
+pub type Mat2 = mat2<f32>;
+pub type Mat3 = mat3<f32>;
+pub type Mat4 = mat4<f32>;
+pub type Mat2x3 = mat2x3<f32>;
+pub type Mat3x2 = mat3x2<f32>;
+pub type Mat2x4 = mat2x4<f32>;
+pub type Mat4x2 = mat4x2<f32>;
+pub type Mat3x4 = mat3x4<f32>;
+pub type Mat4x3 = mat4x3<f32>;
+
 pub type vec2<T> = (T, T);
 pub type vec3<T> = (T, T, T);
 pub type vec4<T> = (T, T, T, T);
+
+pub type mat2<T> = (vec2<T>, vec2<T>);
+pub type mat3<T> = (vec3<T>, vec3<T>, vec3<T>);
+pub type mat4<T> = (vec4<T>, vec4<T>, vec4<T>, vec4<T>);
+pub type mat2x3<T> = (vec3<T>, vec3<T>);
+pub type mat3x2<T> = (vec2<T>, vec2<T>, vec2<T>);
+pub type mat2x4<T> = (vec4<T>, vec4<T>);
+pub type mat4x2<T> = (vec2<T>, vec2<T>, vec2<T>, vec2<T>);
+pub type mat3x4<T> = (vec4<T>, vec4<T>, vec4<T>);
+pub type mat4x3<T> = (vec3<T>, vec3<T>, vec3<T>, vec3<T>);
