@@ -4,22 +4,47 @@ pub type CowStr = std::borrow::Cow<'static, str>;
 pub type Res<T> = Result<T, String>;
 pub type Str = &'static str;
 
+pub fn lambda<'a, T: Fn(A) -> R + 'a, A, R>(f: T) -> Box<dyn Fn(A) -> R + 'a> {
+	Box::new(f)
+}
+
+pub trait UnwrapValid<T> {
+	fn valid(self) -> T;
+}
+impl<T> UnwrapValid<T> for Option<T> {
+	fn valid(self) -> T {
+		#[cfg(debug_assertions)]
+		{
+			self.unwrap()
+		}
+		#[cfg(not(debug_assertions))]
+		{
+			unsafe { self.unwrap_unchecked() }
+		}
+	}
+}
+impl<T, E: Debug> UnwrapValid<T> for Result<T, E> {
+	fn valid(self) -> T {
+		#[cfg(debug_assertions)]
+		{
+			self.unwrap()
+		}
+		#[cfg(not(debug_assertions))]
+		{
+			unsafe { self.unwrap_unchecked() }
+		}
+	}
+}
+
 #[macro_export]
 macro_rules! map_enum {
-	($t: pat = $e: expr => $do: expr) => {
+	($t: pat = $e: expr => $do: expr) => {{
 		if let $t = $e {
 			Some($do)
 		} else {
 			None
 		}
-	};
-}
-
-#[macro_export]
-macro_rules! impl_trait_for {
-	($trait: ty = $($types: ty),+) => {
-		$(impl $trait for $types {})+
-	};
+	}};
 }
 
 pub fn Def<T: Default>() -> T {
@@ -27,21 +52,21 @@ pub fn Def<T: Default>() -> T {
 }
 
 pub trait OrAssignment {
-	fn or_def(self, with: bool) -> Self;
-	fn or_val(self, with: bool, v: Self) -> Self;
+	fn or_def(self, filter: bool) -> Self;
+	fn or_val(self, filter: bool, val: Self) -> Self;
 }
 impl<T: Default> OrAssignment for T {
 	#[inline(always)]
-	fn or_def(self, with: bool) -> Self {
-		if with {
+	fn or_def(self, filter: bool) -> Self {
+		if filter {
 			self
 		} else {
 			Def()
 		}
 	}
 	#[inline(always)]
-	fn or_val(self, with: bool, v: Self) -> Self {
-		if with {
+	fn or_val(self, filter: bool, v: Self) -> Self {
+		if filter {
 			self
 		} else {
 			v
