@@ -1,3 +1,4 @@
+#![allow(clippy::len_without_is_empty, clippy::wrong_self_convention)]
 mod apply;
 mod args;
 mod math;
@@ -9,5 +10,5 @@ pub use {
 	apply::*,
 	math::{TupleComparison, TupleMath, TupleSelf, TupleSigned},
 	ops::{Tuple2Geometry, TupleAllAny, TupleVecIdentity},
-	swizzle::swizzle::*,
+	swizzle::s::*,
 };
